# Algora Labs Python SDK

[Algora Labs](https://algoralabs.com/) is an IDE for Quants. We provide users financial data, a research environment and
visualization tools to efficiently translate research ideas into actionable insights for trading.
The [algora-sdk](https://pypi.org/project/algora-sdk/) allows users to programmatically access datasets and resources on
our platform.

## Installation

When running locally, set the following environment variables for your username and password
for [Algora Labs](https://trade.algoralabs.com/). When running code on our platform, there is no need to set these
environment variables.

```text
ALGORA_USER=username
ALGORA_PWD=password
```

## Contact

Please [Contact Us](mailto:support@algoralabs.com) if you have any questions!
